#pragma region Include
#include<iostream>
#include<fstream>
#include<vector>
#include<map>
#include<set>
#include<algorithm>
#include<cmath>
#include<assert.h>
#include<random>
using namespace std;
#pragma endregion
#pragma region IO
template<typename T>
istream& operator >> (istream& in, vector<T>& v)
{
	for (int i = 0; i < v.size(); i++)
		in >> v[i];
	return in;
}

template<typename T>
ostream& operator << (ostream& out, vector<T> v)
{
	for (int i = 0; i < v.size(); i++)
		out << v[i] << ' ';

	if (!v.empty())
		out << '\n';

	return out;
}

template<typename T>
ostream& operator << (ostream& out, vector<vector<T>> v)
{
	for (int i = 0; i < v.size(); i++)
	{
		for (int j = 0; j < v[i].size(); j++)
			out << v[i][j] << ' ';

		out << '\n';
	}

	return out;
}
#pragma endregion

class RangeTree
{
	int n;
	vector<long long> t;

	void upd_t(int v, int l, int r, int P, long long X)
	{
		if (P < l || r <= P)
			return;

		if (r - l == 1)
		{
			t[v] = X;
			return;
		}

		if ((l + r) / 2 > P)
			upd_t(2 * v, l, (l + r) / 2, P, X);
		else
			upd_t(2 * v + 1, (l + r) / 2, r, P, X);

		t[v] = max(t[2 * v], t[2 * v + 1]);
	}

	long long get_t(int v, int l, int r, int L, int R)
	{
		if (R <= l || r <= L)
			return 0;
		if (L <= l && r <= R)
			return t[v];
		return max(get_t(2 * v, l, (l + r) / 2, L, R), get_t(2 * v + 1, (l + r) / 2, r, L, R));
	}

public:
	RangeTree() : n(0), t(0) {}
	RangeTree(int n) : n(n), t(4 * n) {}

	void upd(int p, long long x)
	{
		upd_t(1, 0, n, p, x);
	}
	long long get(int l, int r)
	{
		return get_t(1, 0, n, l, r);
	}
};

class DpMdf
{
	int n;
	vector<long long> dp, a;
	RangeTree dp_max;

	bool recalc_dp(int pos)
	{
		long long old = dp[pos], sum = 0;
		dp[pos] = dp[pos - 1];
		
		for (int i = 1; i < 4 && pos - i >= 0; i++)
		{
			sum += a[pos - i + 1];
			dp[pos] = max(dp[pos], sum + dp_max.get(0, pos - i));
		}

		dp_max.upd(pos, dp[pos]);
		return old != dp[pos];
	}

	void upd_a(int pos, long long n_a)
	{
		a[pos] = n_a;
		int upd_ptr = min(n, pos + 4);
		for (int i = pos; i < upd_ptr; i++)
			if (recalc_dp(i))
				upd_ptr = min(i + 4, n);
	}

public:
	DpMdf(vector<long long> const& a) : n(a.size()), dp(n), a(a), dp_max(n)
	{
		for (int i = 1; i < n; i++)
			recalc_dp(i);
	}

	long long get()
	{
		return dp_max.get(0, n);
	}

	void upd(int pos, long long n_a)
	{
		if (pos != 0)
			upd_a(pos, n_a);
	}
};

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	int n;
	cin >> n;
	vector<long long> a(n);
	cin >> a;

	vector<DpMdf> v;
	long long ans = 0;

	for (int i = 0; i < 4; i++)
	{
		v.push_back(DpMdf(a));
		ans = max(ans, v[i].get());
		rotate(a.begin(), a.begin() + 1, a.end());
	}

	cout << ans << '\n';

	int q, p, n_a;
	cin >> q;

	while (cin >> p >> n_a)
	{
		ans = 0;
		--p;

		for (int i = 0; i < 4; i++)
		{
			v[i].upd(p, n_a);
			ans = max(ans, v[i].get());
			--p;
			if (p < 0)
				p += n;
		}

		cout << ans << '\n';
	}
}