
#include <iostream>
#include <iomanip>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
#include <cassert>
#include <cstring>
#include <random>
#include <cstdlib>
#include <queue>
#include <deque>

#ifdef __LOCAL
#define DBG(X) cout << #X << "=" << (X) << '\n';
#define SAY(X) cout << (X) << '\n';
#else
#define DBG(X) 42
#define SAY(X) 43
#endif

using namespace std;
using ll = long long int;
using pii = pair<int, int>;
using pll = pair<ll, ll>;

void fast_IO() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
}

template<typename T>
ostream& operator<<(ostream& os, const vector<T>& vec) {
	for(auto& el: vec) os << el << ' ';
	return os;
}

template<typename T, typename S>
ostream& operator<<(ostream& os, const pair<S, T>& pr) {
	os << '[' << pr.first << ' ' << pr.second << ']';
	return os;
}

const int MAXN = (int)2e5 + 7;
int a[MAXN], n;
int nxt[MAXN], lst[MAXN];
ll S[MAXN];
vector<int> ord;
vector<int> disable[MAXN];

ll calc(int i, int d) {
	return min(i, nxt[i] - d) - max(i - d + 1, 0) + 1;
}

namespace TreeL {
struct Data {
	ll sum = 0, mod = 0;
	ll active = 1;
};

Data tree[4 * MAXN];
inline ll read(int v) {
	if(tree[v].active) {
		return tree[v].mod * tree[v].active + tree[v].sum;
	} else {
		return 0;
	}
}

inline void relax(int v) {
	tree[v].sum = read(2*v+1) + read(2*v+2);
	tree[v].active = tree[2*v+1].active + tree[2*v+2].active;
}

inline void push(int v) {
	tree[2*v+1].mod += tree[v].mod;
	tree[2*v+2].mod += tree[v].mod;
	tree[v].sum += tree[v].mod * tree[v].active;
	tree[v].mod = 0;
}

void build(int v, int tl, int tr) {
	if(tl==tr) {
		tree[v].sum = tl;
	} else {
		int tm = (tl+tr)/2;
		build(2 * v + 1, tl, tm);
		build(2 * v + 2, tm + 1, tr);
		relax(v);	
	}
}

void disable(int v, int tl, int tr, int pos) {
	if(tl==tr) {
		tree[v].active = 0;
	} else {
		push(v);
		int tm = (tl+tr)/2;
		if(pos <= tm) {
			disable(2*v+1, tl, tm, pos);
		} else {
			disable(2*v+2, tm + 1, tr, pos);
		}
		relax(v);
	}
}

ll get(int v, int tl, int tr, int l, int r) {
	l = max(l, tl);
	r = min(r, tr);
	if(l>r) return 0;
	if(tl == l && tr == r) {
		return read(v);
	} else {
		push(v);
		int tm = (tl+tr)/2;
		ll left = get(2*v+1, tl, tm, l, r);
		ll right = get(2*v+2, tm + 1, tr, l, r);
		return left+right;
	}
}

void change(int v, int tl, int tr, int l, int r, ll x) {
	l = max(l, tl);
	r = min(r, tr);
	if(l>r) return;
	if(tl == l && tr == r) {
		tree[v].mod += x;
	} else {
		push(v);
		int tm = (tl+tr)/2;
		change(2*v+1, tl, tm, l, r, x);
		change(2*v+2, tm + 1, tr, l, r, x);
		relax(v);
	}
}

}

vector<ll> start[MAXN], finish[MAXN];
vector<ll> ch[MAXN];

void solve() {
	cin >> n;
	ord.resize(n);
	for(int i = 0; i < n; ++i) {
		cin >> a[i];
		ord[i] = a[i];
	}

	sort(ord.begin(), ord.end());
	ord.erase(unique(ord.begin(), ord.end()), ord.end());
	DBG(ord);

	for(int i = 0; i < n; ++i) {
		a[i] = lower_bound(ord.begin(), ord.end(), a[i]) - ord.begin();
	}

	for(int val = 0; val < MAXN; ++val) {
		lst[val] = n;
	}

	for(int i = n - 1; i >= 0; --i) {
		int v = a[i];
		nxt[i] = lst[v];
		lst[v] = i;
	}

	for(int i = 0; i < n; ++i) {
		int low = 1, high = n + 1;
		while(high - low > 1) {
			int mid = (low+high)/2;
			if(calc(i, mid) >= 0) {
				low = mid;
			} else {
				high = mid;
			}
		}

		disable[high].push_back(i);
		/*for(int d = 1; d <= low; ++d) {
			S[d] += i;
		}*/
		ll f = nxt[i] - i + 1;
		/*int cur = -1;
		for(int d = f; d <= low; ++d) {
			S[d] += cur;
			--cur;
		}*/

		if(f <= low) {
			start[f].emplace_back(-1LL);
			finish[low].emplace_back(-(low - f + 1));
		}

		ch[1].emplace_back(i);
		ch[high].emplace_back(-i);

		/*for(int d = 1; d <= low; ++d) {
			S[d] += min(i, nxt[i] - d);
			cout << ' ' <<  min(i, nxt[i] - d);
		}
		cout << '\n';*/
	}

	int cur = n;
	TreeL::build(0, 0, n - 1);
	for(int d = 1; d <= n; ++d) {
		for(auto& i: disable[d]) {
			TreeL::disable(0, 0, n - 1, i);
			--cur;
		}

		//DBG(d);
		//for(int i = 0; i < n; ++i) cout << TreeL::get(0, 0, n - 1, i, i) << ' ';
		//cout << '\n';

		S[d] += cur;
		S[d] -= TreeL::get(0, 0, n - 1, 0, n - 1);
		if(d < n) TreeL::change(0, 0, n - 1, d, n - 1, -1);
	}

	ll sum = 0, bal = 0;
	for(int d = 1; d <= n; ++d) {
		for(auto& v: start[d]) {
			++bal;
			sum += v;
		}

		S[d] += sum;

		for(auto& v: finish[d]) {
			--bal;
			sum -= v;
		}

		sum -= bal;
	}

	sum = 0;
	for(int d = 1; d <= n; ++d) {
		for(auto& v: ch[d]) sum += v;
		S[d] += sum;
	}

	for(int i = 1; i <= n; ++i) cout << S[i] << ' ';
	cout << '\n';
}

int main() {
	fast_IO();
	solve();

	return 0;
}