#include <iostream>
#include <iomanip>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
#include <cassert>
#include <cstring>
#include <random>
#include <cstdlib>
#include <queue>
#include <deque>

#ifdef __LOCAL
#define DBG(X) cout << "[DBG] " #X << "=" << (X) << '\n';
#define SAY(X) cout << (X) << '\n';
#else
#define DBG(X) 42
#define SAY(X) 43
#endif

using namespace std;
using ll = long long int;
using pii = pair<int, int>;
using pll = pair<ll, ll>;
const int NIL = -1;

void fast_IO() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
}

template<typename T>
ostream& operator<<(ostream& os, const vector<T>& vec) {
	for(auto& el: vec) os << el << ' ';
	return os;
}

template<typename T, typename S>
ostream& operator<<(ostream& os, const pair<S, T>& pr) {
	os << '[' << pr.first << ' ' << pr.second << ']';
	return os;
}

const int MAXN  = (int)3e5 + 7;
const int T_AND = 1;
const int T_OR  = 2;

struct Op {
	int type, left, right;
};
vector<Op> ops[MAXN];
vector<int> A[MAXN];
int n, m, s;
int answ[MAXN];

int calc(int r) {
	vector<int> t(2*n-1, NIL);
	for(int j = 0; j < n; ++j) t[j] = A[r][j] < answ[j];
	for(int j = n; j < 2*n-1; ++j) {
		auto& op = ops[r][j - n];
		if(op.type == T_AND) {
			t[j] = t[op.left]&t[op.right];
		} else {
			t[j] = t[op.left]|t[op.right];
		}
	}

	DBG(t);
	return t.back();
}

int brute(int pos) {
	if(pos==n) {
		int cnt = 0;
		for(int r = 0; r < m; ++r) {
			cnt += calc(r);
		}

		return cnt==s;
	} else {
		int& i = answ[pos];
		for(i = 0; i <= m; ++i) {
			int rez = brute(pos + 1);
			if(rez) return rez;
		}
		return 0;
	}
}

struct Node {
	int sum = 0, left = NIL, right = NIL;
};

vector<Node> T;
int create_node() {
	int v = (int)T.size();
	T.emplace_back();
	return v;
}

inline int read(int v) {
	return (v==NIL? 0 : T[v].sum);
}

inline void relax(int v) {
	if(v!=NIL) T[v].sum = read(T[v].left) + read(T[v].right);
}

inline int clone(int v) {
	int v2 = create_node();
	if(v!=NIL) T[v2] = T[v];
	return v2;
}

int change(int v, int tl, int tr, int pos, int ch) {
	if(pos < tl || pos > tr) return v;
	v = clone(v);
	if(tl==tr) {
		T[v].sum += ch;
	} else {
		int tm = (tl+tr)/2;
		T[v].left = change(T[v].left, tl, tm, pos, ch);
		T[v].right = change(T[v].right, tm + 1, tr, pos, ch);
		relax(v);
	}
	return v;
}

int get(int v, int tl, int tr, int l, int r) {
	l = max(l, tl);
	r = min(r, tr);
	if(l>r||v==NIL) return 0;
	if(tl==l&&tr==r) {
		return read(v);
	} else {
		int tm = (tl+tr)/2;
		int left = get(T[v].left, tl, tm, l, r);
		int right = get(T[v].right, tm + 1, tr, l, r);
		return left+right;
	}
}

const int X = (int)1e5 + 777;
int OR[X], AND[X];

int __getAND(int s, int t) {
	if(s==0||t==0) return 0;
	return get(AND[s - 1], 0, X - 1, 0, t - 1);
}

int __getOR(int s, int t) {
	int rez = 0;
	if(s!=0) rez += get(OR[s - 1], 0, X - 1, 0, X - 1);
	if(t!=0) rez += get(OR[X - 1], 0, X - 1, 0, t - 1);
	if(s!=0&&t!=0) rez -= get(OR[s - 1], 0, X - 1, 0, t - 1);
	return rez;
}

int count(int i, int j) {
	return __getAND(i, j)+__getOR(i, j);
}

const int S = 1007;
int cntOR[S][S], cntAND[S][S];

int getAND(int s, int t) {
	if(s==0||t==0) return 0;
	return cntAND[s - 1][t - 1];
}

int getOR(int s, int t) {
	int rez = 0;
	if(s!=0) rez += cntOR[s - 1][S - 1];
	if(t!=0) rez += cntOR[S - 1][t - 1];
	if(s!=0&&t!=0) rez -= cntOR[s - 1][t - 1];

	return rez;
}

void solve() {
	cin >> n >> m >> s;
	for(int r = 0; r < m; ++r) {
		ops[r].resize(n - 1);
		for(auto& el: ops[r]) {
			cin >> el.left >> el.right >> el.type;
			--el.left, --el.right;
		}
	}
	for(int r = 0; r < m; ++r) {
		A[r].resize(n);
		for(auto& el: A[r]) cin >> el;
	}

	int is_subtask4 = 1;
	int is_subtask5 = 1;
	for(int r = 0; r < m; ++r) {
		for(int j = 0; j < n; ++j) {
			if(A[r][j]!=r) {
				is_subtask4 = 0;
				break;
			}
		}

		if(is_subtask4==0) break;
	}

	for(int r = 0; r < m; ++r) {
		for(auto& op: ops[r]) {
			if(op.type!=T_AND) {
				is_subtask5 = 0;
				break;
			}
		}

		if(is_subtask5==0) break;
	}

#ifdef __LOCAL
	goto L;
#endif

	if(n <= 10 && m <= 2) {
		int rez = brute(0); DBG(rez);
		for(int i = 0; i < n; ++i) cout << answ[i] << ' ';
		cout << '\n';
		return;
	}

	if(is_subtask4) {
		for(int i = 0; i < n; ++i) cout << s << ' ';
		cout << '\n';
		return;
	}

	if(is_subtask5) {
		for(int i = 0; i < n; ++i) cout << (i==0? s : m)  << ' ';
		cout << '\n';
		return;
	}

	if(n == 1) {
		cout << s << '\n';
		return;
	}

	if(n == 2 && m <= 1000) {
		for(int r = 0; r < m; ++r) {
			int x = A[r].front();
			int y = A[r].back();
			if(ops[r].front().type==T_AND) {
				++cntAND[x][y];
			} else {
				++cntOR[x][y];
			}
		}

		for(int i = 0; i < S; ++i) {
			for(int j = 1; j < S; ++j) {
				cntOR[i][j] += cntOR[i][j - 1];
				cntAND[i][j] += cntAND[i][j - 1];
			}

			if(i==0) continue;
			for(int j = 0; j < S; ++j) {
				cntOR[i][j] += cntOR[i - 1][j];
				cntAND[i][j] += cntAND[i - 1][j];
			}
		}

		for(int i = 0; i <= m; ++i) {
			for(int j = 0; j <= m; ++j) {
				int cnt = getOR(i, j)+getAND(i, j);
				if(cnt==s) {
					cout << i << ' ' << j << '\n';
					return;
				}
			}
		}

		assert(false);
	}

	L:
	if(n == 2 && m <= 100 * 1000) {
		SAY("presistend segtree");
		int rtOR = NIL, rtAND = NIL;
		vector<pii> prOR, prAND;
		for(int r = 0; r < m; ++r) {
			int x = A[r].front();
			int y = A[r].back();
			if(ops[r].front().type==T_AND) {
				prAND.emplace_back(x, y);
			} else {
				prOR.emplace_back(x, y);
			}
		}

		memset(OR, NIL, sizeof(OR));
		memset(AND, NIL, sizeof(AND));

		sort(prOR.begin(), prOR.end());
		sort(prAND.begin(), prAND.end());
		for(auto& pr: prOR) {
			rtOR = change(rtOR, 0, X - 1, pr.second, +1);
			OR[pr.first] = rtOR;
		}
		OR[X - 1] = rtOR;
		for(auto& pr: prAND) {
			rtAND = change(rtAND, 0, X - 1, pr.second, +1);
			AND[pr.first] = rtAND;
		}
		AND[X - 1] = rtAND;

		for(int i = X - 2; i >= 0; --i) {
			if(OR[i]==NIL)OR[i] = OR[i + 1];
			if(AND[i]==NIL)AND[i] = AND[i + 1];
		}

		for(int i = 0; i <= m; ++i) {
			int low = 0, high = m;
			while(high - low > 1) {
				int mid = (low+high)/2;
				if(count(i, mid)<=s) {
					low = mid;
				} else {
					high = mid;
				}
			}

			if(count(i, low)==s) {
				cout << i << ' ' << low << '\n';
				return;
			}

			if(count(i, high)==s) {
				cout << i << ' ' << high << '\n';
				return;
			}
		}

		assert(false);
	}

	assert(false);
}

int main() {
	fast_IO();
	solve();

	return 0;
}