#include <iostream>
#include <iomanip>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
#include <cassert>
#include <cstring>
#include <random>
#include <cstdlib>
#include <queue>
#include <deque>

#ifdef __LOCAL
#define DBG(X) cout << #X << "=" << (X) << '\n';
#define SAY(X) cout << (X) << '\n';
#else
#define DBG(X) 42
#define SAY(X) 43
#endif

using namespace std;
using ll = long long int;
using pii = pair<int, int>;
using pll = pair<ll, ll>;
const int NIL = -1;
const ll LL_INF = (ll)2e18;

void fast_IO() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);
}

template<typename T>
ostream& operator<<(ostream& os, const vector<T>& vec) {
	for(auto& el: vec) os << el << ' ';
	return os;
}

template<typename T, typename S>
ostream& operator<<(ostream& os, const pair<S, T>& pr) {
	os << '[' << pr.first << ' ' << pr.second << ']';
	return os;
}

const int MAXN = (int)4e4 + 77;
const int K    = 4;
vector<int> ord[K], pos[K];
ll a[K][MAXN];
int n, q;

struct Data {
	ll dp[K][K];
	int leng;
};

Data combine(const Data& lhs, const Data& rhs) {
	Data rez;
	for(int a = 0; a < K; ++a) {
		for(int b = 0; b < K; ++b) {
			rez.dp[a][b] = -LL_INF;
		}
	}
	rez.leng = lhs.leng + rhs.leng;

	for(int a = 0; a < K; ++a) {
		for(int b = 0; b < K; ++b) {
			if(lhs.dp[a][b] < 0) continue;
			for(int c = 0; c < K - b; ++c) {
				for(int d = 0; d < K; ++d) {
					if(rhs.dp[c][d] < 0) continue;
					ll sum = lhs.dp[a][b] + rhs.dp[c][d];
					int a2 = (a < lhs.leng ? a : a + c);
					int b2 = (d < rhs.leng ? d : b + d);
					rez.dp[a2][b2] = max(rez.dp[a2][b2], sum);
				}
			}
		}
	}

	return rez;
}

struct Tree {
	vector<Data> T;
	vector<int> leaf, pa;// L, R;

	int sz;
	Data neutral;
	void build(int v, int ii, int tl, int tr) {
		//L[v] = tl; R[v] = tr;
		if(tl == tr) {
			ll x = a[ii][tl];
			for(int a = 0; a < K; ++a) {
				for(int b = 0; b < K; ++b) {
					T[v].dp[a][b] = -LL_INF;
				}
			}

			T[v].dp[0][0] = 0;
			T[v].dp[1][1] = x;
			T[v].leng = 1;
			leaf[tl] = v;
		} else {
			int tm = (tl+tr)/2;
			build(2 * v + 1, ii, tl, tm);
			build(2 * v + 2, ii, tm + 1, tr);
			T[v] = combine(T[2 * v + 1], T[2 * v + 2]);
			pa[2 * v + 1] = v;
			pa[2 * v + 2] = v;
		}

		/*cout << "@node: " << v << ' ' << tl << ' ' << tr << '\n';
		for(int a = 0; a < K; ++a) {
			for(int b = 0; b < K; ++b) {
				cout << a << ' ' << b << ' ' << T[v].dp[a][b] << '\n';
			}
		}*/
	}

	void change(int pos, ll val) {
		int v = leaf[pos];
		T[v].dp[1][1] = val;
		while(v != 0) {
			v = pa[v];
			T[v] = combine(T[2 * v + 1], T[2 * v + 2]);
		}
	}

	Tree(int ii, int _sz): sz(_sz) {
		T.resize(4 * sz);
		leaf.resize(sz);
		pa.resize(4 * sz);
		//L.resize(4 * sz);
		//R.resize(4 * sz);
		for(int a = 0; a < K; ++a) {
			for(int b = 0; b < K; ++b) {
				neutral.dp[a][b] = -LL_INF;
			}
		}
		neutral.dp[0][0] = 0;
		build(0, ii, 0, sz - 1);
	}
};

void assign(int p, int x, int call_tree, const vector<Tree*> trees) {
	for(int i = 0; i < K; ++i) {
		int id = pos[i][p];
		if(id == NIL) continue;
		a[i][id] = x;

		if(call_tree) {
			auto tree = trees[i];
			tree->change(id, x);
		}
	}
}

ll fetch(const vector<Tree*>& trees) {
	ll rez = 0;
	for(int ii = 0; ii < K; ++ii) {
		auto tree = trees[ii];
		auto d = tree->T[0];
		for(int a = 0; a < K; ++a) {
			for(int b = 0; b < K; ++b) {
				rez = max(rez, d.dp[a][b]);
			}
		}
	}
	return rez;
}

void solve() {
	cin >> n;
	for(int i = 0; i < K; ++i) {
		pos[i].resize(n, NIL);
		for(int j = i + 1; j < n; ++j) ord[i].push_back(j);
		for(int j = 0; j < i; ++j) ord[i].push_back(j);
		for(int p = 0; p < n - 1; ++p) {
			pos[i][ord[i][p]] = p;
		}

		DBG(ord[i]);
		DBG(pos[i]);
	}

	vector<Tree*> trees(K, nullptr);
	for(int i = 0; i < n; ++i) {
		int x; cin >> x;
		assign(i, x, 0, trees);
	}

	for(int ii = 0; ii < K; ++ii) {
		trees[ii] = new Tree(ii, n - 1);
	}

	int q; cin >> q;
	cout << fetch(trees) << '\n';
	while(q--) {
		int pos, val; cin >> pos >> val; --pos;
		assign(pos, val, 1, trees);
		cout << fetch(trees) << '\n';
	}
}

int main() {
	fast_IO();
	solve();

	return 0;
}