//#define PYHAEM_S_NOGI


#pragma GCC optimize("unroll-loops,no-stack-protector,btr-bb-exclusive,fast-math")
#pragma GCC optimize("Ofast")

#include <bits/stdc++.h>

using namespace std;

#define int long long


#ifdef PYHAEM_S_NOGI

const int MEMORY_SIZE = 300 * 1024 * 1024;

char MEMORY[MEMORY_SIZE];
char* allocptr = MEMORY;

void* operator new(size_t sz) {
	void* ptr = allocptr;
	allocptr += sz;
	assert(allocptr <= MEMORY + MEMORY_SIZE);
	return ptr;
}
void operator delete(void*) {
}

#endif

class DynamicArray {
public:
	int capacity;
	int size;
	int* data;

	DynamicArray() {
		capacity = 10;
		size = 0;
		data = new int[capacity];
	}

	int operator[] (int i) {
		return data[i];
	}

	void push_back(int x) {
		if(size == capacity) {
			capacity *= 2;
			int* newptr = new int[capacity];
			memmove(newptr, data, size);
			delete[] data;
			data = newptr;
		}
		data[size++] = x;
	}

	int* begin() {
		return data;
	}
	int* end() {
		return data + size;
	}
};


const int BUFFER_SIZE = 32768;

char readbuf[BUFFER_SIZE];
char* readbufptr = readbuf;
char* readbufend = readbuf;

int readch() {
	if(readbufptr == readbufend) {
		readbufend = readbuf + fread_unlocked(readbuf, 1, BUFFER_SIZE, stdin);
		if(readbufend == readbuf) {
			return -1;
		}
		readbufptr = readbuf;
	}
	return *readbufptr++;
}

int readint() {
	int c;
	do {
		c = readch();
	} while(c <= ' ');
	int sign = 1;
	if(c == '-') {
		sign = -1;
		c = readch();
	}
	int num = 0;
	do {
		num = num * 10 + (c - '0');
		c = readch();
	} while(c > ' ');
	return num * sign;
}


class SegmentTree {
	int n;
	vector<int> a;

public:
	SegmentTree(int sz) {
		n = sz;
		a.resize(4 * n);
	}

	int get(int v, int vl, int vr, int l, int r) {
		if(vl == l && vr == r) {
			return a[v];
		}
		int vm = (vl + vr) / 2;
		if(r <= vm) {
			return get(v * 2, vl, vm, l, r);
		} else if(l >= vm) {
			return get(v * 2 + 1, vm, vr, l, r);
		} else {
			return get(v * 2, vl, vm, l, vm) + get(v * 2 + 1, vm, vr, vm, r);
		}
	}
	int get(int l, int r) {
		if(l == r) {
			return 0;
		}
		return get(1, 0, n, l, r);
	}
	int get(int i) {
		return get(i, i + 1);
	}

	void set(int v, int vl, int vr, int i, int x) {
		if(vr - vl == 1) {
			a[v] = x;
			return;
		}
		int vm = (vl + vr) / 2;
		if(i < vm) {
			set(v * 2, vl, vm, i, x);
		} else {
			set(v * 2 + 1, vm, vr, i, x);
		}
		a[v] = a[v * 2] + a[v * 2 + 1];
	}
	void set(int i, int x) {
		set(1, 0, n, i, x);
	}
};


class Vertex {
public:
	int y;
	int sz;
	int value;
	Vertex *left, *right;

	Vertex(int v): y(rand()), sz(1), value(v), left(nullptr), right(nullptr) {}

	void pull() {
		sz = (left ? left->sz : 0) + 1 + (right ? right->sz : 0);
	}
};

class Treap {
public:
	Vertex *root;

	Treap() {
		root = nullptr;
	}

	pair<Vertex*, Vertex*> split(Vertex* v, int pos) {
		if(v == nullptr) {
			return make_pair(nullptr, nullptr);
		}
		if((v->left ? v->left->sz : 0) >= pos) {
			auto p = split(v->left, pos);
			v->left = p.second;
			v->pull();
			return make_pair(p.first, v);
		} else {
			auto p = split(v->right, pos - (v->left ? v->left->sz : 0) - 1);
			v->right = p.first;
			v->pull();
			return make_pair(v, p.second);
		}
	}

	Vertex* merge(Vertex* a, Vertex* b) {
		if(a == nullptr) {
			return b;
		}
		if(b == nullptr) {
			return a;
		}
		if(a->y > b->y) {
			a->right = merge(a->right, b);
			a->pull();
			return a;
		} else {
			b->left = merge(a, b->left);
			b->pull();
			return b;
		}
	}

	void insert(int i, Vertex* v) {
		auto p = split(root, i);
		root = merge(p.first, merge(v, p.second));
	}
	void insert(int i, int x) {
		insert(i, new Vertex(x));
	}

	int get(int i) {
		auto p = split(root, i);
		auto pp = split(p.second, 1);
		assert(pp.first != nullptr);
		int val = pp.first->value;
		root = merge(p.first, merge(pp.first, pp.second));
		return val;
	}

	void remove(int i) {
		auto p = split(root, i);
		auto pp = split(p.second, 1);
		root = merge(p.first, pp.second);
		delete pp.first;
	}
};


class Point {
public:
	double x, y;
	Point(double x, double y): x(x), y(y) {}
};

class Vector {
public:
	double x, y;
	Vector(double x, double y): x(x), y(y) {}
	Vector(Point a, Point b): x(b.x - a.x), y(b.y - a.y) {}
	Vector operator+ (const Vector other) const {
		return Vector(x + other.x, y + other.y);
	}
	Vector operator- (const Vector other) const {
		return Vector(x - other.x, y - other.y);
	}
	Vector operator- () const {
		return Vector(-x, -y);
	}
	double operator* (const Vector other) const {
		return x * other.x + y * other.y;
	}
	double operator% (const Vector other) const {
		return x * other.y - y * other.x;
	}
};

Point operator+ (Point a, Vector v) {
	return Point(a.x + v.x, a.y + v.y);
}

class Line {
public:
	double a, b, c;
	Line(Point p1, Point p2) {
		a = p2.y - p1.y;
		b = p1.x - p2.x;
		c = -(a * p1.x + b * p1.y);
	}

	Point operator& (const Line other) const {
		auto a1 = a, b1 = b, c1 = c, a2 = other.a, b2 = other.b, c2 = other.c;
		double x = (c1 * b2 - c2 * b1) / (a2 * b1 - a1 * b2);
		double y = (c1 * a2 - c2 * a1) / (b2 * a1 - b1 * a2);
		return Point(x, y);
	}
};


void solve() {
	int n;
	cin >> n;

	int limit = (1LL << 62) - 1;

	if(n == 0) {
		cout << "Yes\n1 1";
		return;
	}

	for(int i = 1; i * i <= n && clock() < CLOCKS_PER_SEC; i++) {
		if(n % i == 0) {
			int diff = i;
			int sum = n / i;
			if((diff + sum) % 2 == 0) {
				int x = (diff + sum) / 2;
				int y = (sum - diff) / 2;
				if(1 <= x && x <= limit && 1 <= y && y <= limit) {
					cout << "Yes\n" << x << " " << y << endl;
					return;
				}
			}
		}
	}

	cout << "No\n";
}

signed main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	solve();

#ifdef PYHAEM_S_NOGI
	cerr << "\nMemory usage: " << (double)(10000 * (allocptr - MEMORY) / MEMORY_SIZE) / 100 << "%\n";
#endif

	return 0;
}