#include <iostream>
#include <algorithm>
#include <vector>
#include <cassert>
#include <map>
#include <deque>

using namespace std;

const long long INF = 1'000'000'000'000'000;
const int k = 333;

struct Segment {
    long long val[16];
    Segment(vector <long long>& a) {
        for (int i = 0; i < 16; i++)
            val[i] = a[i];
    }
    Segment() {
        for (int i = 0; i < 16; i++)
            val[i] = -INF;
    }
    long long get(int i, int j) {
        return val[i * 4 + j];
    }
};

long long get_cost(vector <Segment>& a) {
    vector <vector <long long>> dp(a.size(), { -INF, -INF, -INF, -INF });
    dp[0] = { a[0].get(0, 0), a[0].get(0, 1), a[0].get(0, 2), a[0].get(0, 3) };
    for (int i = 1; i < a.size(); i++) {
        for (int prev = 0; prev < 4; prev++) {
            for (int cur = 0; cur < 4; cur++) {
                dp[i][cur] = max(dp[i][cur], a[i].get(3 - prev, cur) + dp[i - 1][prev]);
            }
        }
    }
    long long cur_ans = *max_element(dp.back().begin(), dp.back().end());
    dp.clear();
    dp.resize(a.size(), { 0, -INF, -INF, -INF });
    dp[0] = { a[0].get(3, 0), a[0].get(3, 1), a[0].get(3, 2), a[0].get(3, 3) }; 
    for (int i = 1; i < a.size(); i++) {
        for (int prev = 0; prev < 4; prev++) {
            for (int cur = 0; cur < 4; cur++) {
                dp[i][cur] = max(dp[i][cur], a[i].get(3 - prev, cur));
            }
        }
    }
    cur_ans = max(cur_ans, dp.back()[0]);
    return cur_ans;
}

vector <long long> get_cost(vector <int> &a, int L, int R) {
    vector <vector <long long>> dp(R - L, { 0, -INF, -INF, -INF });
    dp[0][1] = a[L];
    for (int i = 1; i < R - L; i++) {
        dp[i][0] = *max_element(dp[i - 1].begin(), dp[i - 1].end());
        for (int j = 1; j < 4; j++) {
            dp[i][j] = dp[i - 1][j - 1] + a[i + L];
        }
    }
    return dp.back();
}

Segment build_segment(vector <int>& a, int L, int R) {
    Segment ans;
    if (L + 1 < R) {
        auto tmp = get_cost(a, L + 1, R);
        for (int j = 0; j < 4; j++) {
            ans.val[j] = tmp[j];
            if (j != 0)
                ans.val[j] = max(ans.val[j], ans.val[j - 1]);
        }
    }
    long long sum = 0;
    for (int i = 1; i < 4; i++) {
        if (L + i < R) {
            sum += a[L + i - 1];
            auto tmp = get_cost(a, L + i + 1, R);
            tmp[0] = max(0ll, tmp[0]);
            for (int j = 0; j < 4; j++) {
                ans.val[i * 4 + j] = tmp[j] + sum;
                if (j != 0)
                    ans.val[i * 4 + j] = max(ans.val[i * 4 + j], ans.val[i * 4 + j - 1]);
            }
        }
    }
    for (int i = 4; i < 16; i++) {
        ans.val[i] = max(ans.val[i - 4], ans.val[i]);
    }
    return ans;
}


int main() {
    ios::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    int n;
    cin >> n;
    vector <int> a(n);
    for (auto& u : a)
        cin >> u;
    vector <Segment> dec(n / k + 1);
    for (int i = 0; i < n; i += k) {
        dec[i / k] = build_segment(a, i, min(n, i + k));
    }
    cout << get_cost(dec) << '\n';
    int q;
    cin >> q;
    for (int i = 0; i < q; i++) {
        int p, val;
        cin >> p >> val, p--;
        a[p] = val;
        dec[p / k] = build_segment(a, p - p % k, min(p - p % k + k, n));
        cout << get_cost(dec) << '\n';
    }
}