#include <iostream>
#include <algorithm>
#include <vector>
#include <cassert>
#include <map>
#include <deque>

using namespace std;

const long long INF = 1'000'000'000'000'000;
int k = 512;

struct Segment {
    long long val[4][4];
    Segment() {
        for (int i = 0; i < 4; i++)
            for (int j = 0; j < 4; j++)
                val[i][j] = -INF;
    }
    long long get(int i, int j) {
        return val[i][j];
    }
};

long long get_cost(vector <Segment>& a) {
    if (a.size() == 1) {
        long long ans = 0;
        ans = max(ans, a[0].get(3, 0));
        ans = max(ans, a[0].get(1, 2));
        ans = max(ans, a[0].get(2, 1));
        ans = max(ans, a[0].get(0, 3));
        return ans;
    }
    vector <vector <long long>> dp(a.size(), { -INF, -INF, -INF, -INF });
    dp[0] = { a[0].get(0, 0), a[0].get(0, 1), a[0].get(0, 2), a[0].get(0, 3) };
    for (int i = 1; i < a.size(); i++) {
        for (int prev = 0; prev < 4; prev++) {
            for (int cur = 0; cur < 4; cur++) {
                dp[i][cur] = max(dp[i][cur], a[i].get(3 - prev, cur) + dp[i - 1][prev]);
            }
        }
    }
    long long cur_ans = *max_element(dp.back().begin(), dp.back().end());
    dp.clear();
    dp.resize(a.size(), { 0, -INF, -INF, -INF });
    dp[0] = { a[0].get(3, 0), a[0].get(3, 1), a[0].get(3, 2), a[0].get(3, 3) }; 
    for (int i = 1; i < a.size(); i++) {
        for (int prev = 0; prev < 4; prev++) {
            for (int cur = 0; cur < 4; cur++) {
                dp[i][cur] = max(dp[i][cur], a[i].get(3 - prev, cur));
            }
        }
    }
    cur_ans = max(cur_ans, dp.back()[0]); 
    dp.clear();
    dp.resize(a.size(), { 0, -INF, -INF, -INF });
    dp[0] = { a[0].get(2, 0), a[0].get(2, 1), a[0].get(2, 2), a[0].get(2, 3) };
    for (int i = 1; i < a.size(); i++) {
        for (int prev = 0; prev < 4; prev++) {
            for (int cur = 0; cur < 4; cur++) {
                dp[i][cur] = max(dp[i][cur], a[i].get(3 - prev, cur));
            }
        }
    }
    cur_ans = max(cur_ans, *max_element(dp.back().begin(), dp.back().begin() + 2));
    dp.clear();
    dp.resize(a.size(), { 0, -INF, -INF, -INF });
    dp[0] = { a[0].get(1, 0), a[0].get(1, 1), a[0].get(1, 2), a[0].get(1, 3) };
    for (int i = 1; i < a.size(); i++) {
        for (int prev = 0; prev < 4; prev++) {
            for (int cur = 0; cur < 4; cur++) {
                dp[i][cur] = max(dp[i][cur], a[i].get(3 - prev, cur));
            }
        }
    }
    cur_ans = max(cur_ans, *max_element(dp.back().begin(), dp.back().begin() + 3));
    return cur_ans;
}

vector <long long> get_cost(vector <int> &a, int L, int R) {
    if (L == R) {
        return { 0, -INF, -INF, -INF };
    }
    vector <vector <long long>> dp(R - L, { 0, -INF, -INF, -INF });
    dp[0][1] = a[L];
    for (int i = 1; i < R - L; i++) {
        dp[i][0] = *max_element(dp[i - 1].begin(), dp[i - 1].end());
        for (int j = 1; j < 4; j++) {
            dp[i][j] = dp[i - 1][j - 1] + a[i + L];
        }
    }
    return dp.back();
}

Segment build_segment(vector <int>& a, int L, int R) {
    Segment ans;
    long long sum = 0;
    for (int i = 0; i < 4; i++) {
        if (i != 0)
            sum += a[L + i - 1];
        auto tmp = get_cost(a, L + i + 1, R);
        for (int j = 0; j < 4; j++) {
            ans.val[i][j] = tmp[j] + sum;
        }
    }
    for (int i = 0; i < 4; i++) {
        for (int j = 0; j < 4; j++) {
            if (i != 0)
                ans.val[i][j] = max(ans.val[i][j], ans.val[i - 1][j]);
            if (j != 0)
                ans.val[i][j] = max(ans.val[i][j], ans.val[i][j - 1]);
        }
    }
    return ans;
}


int main() {
    ios::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    int n;
    cin >> n;
    vector <int> a(n);
    for (auto& u : a)
        cin >> u;
    while (n % k < 4) {
        k--;
    }
    vector <Segment> dec(n / k + 1);
    for (int i = 0; i < n; i += k) {
        dec[i / k] = build_segment(a, i, min(n, i + k));
    }
    cout << get_cost(dec) << '\n';
    int q;
    cin >> q;
    for (int i = 0; i < q; i++) {
        int p, val;
        cin >> p >> val, p--;
        a[p] = val;
        dec[p / k] = build_segment(a, p - p % k, min(p - p % k + k, n));
        cout << get_cost(dec) << '\n';
    }
}