#include <type_traits>
#include <algorithm>
#include <iostream>
#include <vector>
#include <cmath>
#include <map>
#include <set>

using namespace std;

typedef long long ll;
typedef pair<ll, ll> pll;
typedef vector<ll> vl;
typedef vector<vl> vvl;

const ll INF = 1000000007LL;


ll sizet = 1LL;

struct Tree
{
	vl tree, treeAdd;
	Tree(vl& arr)
	{
		while (sizet < (ll)arr.size()) { sizet *= 2LL; }
		tree.resize(sizet * 2LL);
		treeAdd.resize(sizet * 2LL);
		for (ll i = sizet; i < sizet + (ll)arr.size(); i++)
		{
			tree[i] = arr[i - sizet];
		}
		for (ll i = sizet - 1LL; i > 0LL; i--)
		{
			tree[i] = tree[i * 2LL] + tree[i * 2LL + 1LL];
		}
	}
	void push(ll n = 1LL, ll tl = 0LL, ll tr = sizet)
	{
		if (treeAdd[n] != 0LL)
		{
			tree[n] += treeAdd[n] * (tr - tl);
			if (n < sizet)
			{
				treeAdd[n * 2LL] += treeAdd[n];
				treeAdd[n * 2LL + 1LL] += treeAdd[n];
			}
			treeAdd[n] = 0LL;
		}
	}
	void update(ll l, ll r, ll x, ll n = 1LL, ll tl = 0LL, ll tr = sizet)
	{
		push(n, tl, tr);
		if (l >= tr || tl >= r) { return; }
		if (l <= tl && tr <= r)
		{
			treeAdd[n] += x;
			push(n, tl, tr);
			return;
		}
		ll mid = (tl + tr) / 2LL;
		update(l, r, x, n * 2LL, tl, mid);
		update(l, r, x, n * 2LL + 1LL, mid, tr);
		tree[n] = tree[n * 2LL] + tree[n * 2LL + 1LL];
		return;
	}
	ll result(ll l, ll r, ll n = 1LL, ll tl = 0LL, ll tr = sizet)
	{
		push(n, tl, tr);
		if (l >= tr || tl >= r) { return 0LL; }
		if (l <= tl && tr <= r) { return tree[n]; }
		ll mid = (tl + tr) / 2LL;
		return result(l, r, n * 2LL, tl, mid) + result(l, r, n * 2LL + 1LL, mid, tr);
	}
};

vl solve(ll n, const vl& arr)
{
	vl S(n);
	for (ll i = 0LL; i < n; i++) { S[i] = (i + 1LL) * (n - i); }
	Tree root(S);
	map<ll, vl> m;
	for (ll i = 0LL; i < n; i++) { m[arr[i]].push_back(i); }
	for (auto it = m.begin(); it != m.end(); it++)
	{
		for (ll is = 0LL; is < (ll)it->second.size() - 1LL; is++)
		{
			root.update(it->second[is + 1LL] - it->second[is], n, -1LL);
		}
	}
	for (ll i = 0LL; i < n; i++) { S[i] = root.result(i, i + 1LL); }
	return S;
}

vl stupid(ll n, const vl& arr)
{
	vl S(n);
	for (ll i = 0LL; i < n; i++)
	{
		set<ll> t;
		for (ll j = i; j < n; j++)
		{
			t.insert(arr[j]);
			S[j - i] += (ll)t.size();
		}
	}
	return S;
}

int main() 
{
	ios_base::sync_with_stdio(false);
	cin.tie(), cout.tie(), cerr.tie();
	/*
	ll t; cin >> t;
	srand(t);
	while (true)
	{
		ll n = rand() % 51LL;
		vl arr(n);
		for (ll i = 0LL; i < n; i++)
		{
			arr[i] = rand() % 51LL;
		}
		vl trueS = stupid(n, arr), maybeS = solve(n, arr);
		if (trueS == maybeS) { continue; }
		if (n > 10LL) { continue; }
		cout << n << endl;
		cout << endl << "Array: ";
		for (ll i = 0LL; i < n; i++)
		{
			cout << arr[i] << " ";
		}
		cout << endl;
		cout << endl << "trueS: ";
		for (ll i = 0LL; i < n; i++)
		{
			cout << trueS[i] << " ";
		}
		cout << endl;
		cout << endl << "falseS: ";
		for (ll i = 0LL; i < n; i++)
		{
			cout << maybeS[i] << " ";
		}
		cout << endl;
		break;
	}
	*/
	int n; cin >> n;
	if (n > 5000) { return 1; }
	int a[200001], S[200001];
	for (int i = 0; i < n; ++i) { cin >> a[i]; S[i] = 0; }
	for (int i = 0; i < n; ++i)
	{
		set<int> t;
		for (int j = i; j < n; ++j)
		{
			t.insert(a[j]);
			S[j - i] += t.size();
		}
	}
	for (int i = 0; i < n; ++i)
	{
		cout << S[i] << " ";
	}
	cout << "\n";
	return 0;
}