#include <iostream>
#include <vector>
#include <algorithm>
#include <string>


using namespace std;


void fast_io() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
}


#define int long long


const int INF = (int)1e14;


#define left(v) 2 * v + 1
#define right(v) 2 * v + 2

class LST {
    vector<vector<vector<int>>> data;
    vector<int> sz;
    vector<int> a;
    int n;

    void merge(int ld, int rd, int cd) {
        auto &a = data[ld];
        auto &b = data[rd];
        auto r = vector<vector<int>>(4, vector<int>(4, -INF));

        for (int al = 0; al < 4; ++al) {
            for (int ar = 0; ar < 4; ++ar) {
                for (int bl = 0; ar + bl < 4; ++bl) {
                    for (int br = 0; br < 4; ++br) {
                        int cur = a[al][ar] + b[bl][br];

                        int cl = al;
                        if (al == sz[ld]) {
                            cl += bl;
                        }

                        int cr = br;
                        if (br == sz[rd]) {
                            cr += ar;
                        }

                        if (cl > 3 || cr > 3) {
                            continue;
                        }

                        if (cur > r[cl][cr]) {
                            r[cl][cr] = cur;
                        }
                    }
                }
            }
        }

        data[cd] = r;
    }

    void update(int v) {
        merge(left(v), right(v), v);
    }

    void build(int l, int r, int v = 0) {
        if (r - l == 1) {
            data[v][0][0] = 0;
            data[v][1][1] = a[l];
            sz[v] = 1;

            return;
        }

        int mid = (l + r) / 2;

        build(l, mid, left(v));
        build(mid, r, right(v));

        update(v);

        sz[v] = sz[left(v)] + sz[right(v)];
    }

    void set(int i, int x, int l, int r, int v = 0) {
        if (r - l == 1) {
            data[v][1][1] = x;

            return;
        }

        int mid = (l + r) / 2;

        if (i < mid) {
            set(i, x, l, mid, left(v));
        } else {
            set(i, x, mid, r, right(v));
        }

        update(v);
    }

public:
    LST(int _n, vector<int> _a) : n(_n), a(_a) {
        data.resize(4 * n, vector<vector<int>>(4, vector<int>(4, -INF)));
        sz.resize(4 * n);

        build(0, n);
    }

    void set(int i, int x) {
        set(i, x, 0, n);
    }

    int get() {
        int res = 0;
        for (int l = 0; l < 4; ++l) {
            for (int r = 0; l + r < 4; ++r) {
                res = max(res, data[0][l][r]);
            }
        }

        return res;
    }
};


signed main() {
    fast_io();

    int n;
    cin >> n;

    vector<int> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
    }

    LST tree(n, a);
    cout << tree.get() << '\n';

    int q;
    cin >> q;

    int p, v;
    while (q--) {
        cin >> p >> v;

        --p;

        tree.set(p, v);

        cout << tree.get() << '\n';
    }

    return 0;
}
